@@ -3,7 +3,7 @@ package DayDayUp;
 use strict;
 use warnings;
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 use base 'Mojolicious';
 
@@ -40,6 +40,8 @@ sub startup {
     # route
     $r->route('/notes/:id/:action', id => qr/\d+/)
       ->to(controller => 'notes', action => 'index');
+    $r->route('/contacts/:id/:action', id => qr/\d+/)
+      ->to(controller => 'contacts', action => 'index');
     # Default route
     $r->route('/:controller/:action')
       ->to(controller => 'index', action => 'index');
